Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2014-04-11 05:47:07 +0400
committerCampbell Barton <ideasman42@gmail.com>2014-04-11 05:47:07 +0400
commit3216e4b202195ed88455d1b43b348a2cf8f40d77 (patch)
tree48b91e2916e48c74cc780f4ef2df538949bccf31 /source/gameengine
parenta15b3c4d111613993eca23d5f99600c2052469e7 (diff)
API Cleanup: Use BKE_constraint prefix for constraint api
Diffstat (limited to 'source/gameengine')
-rw-r--r--source/gameengine/Converter/BL_ArmatureObject.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/gameengine/Converter/BL_ArmatureObject.cpp b/source/gameengine/Converter/BL_ArmatureObject.cpp
index 3eb782961e3..0392280444d 100644
--- a/source/gameengine/Converter/BL_ArmatureObject.cpp
+++ b/source/gameengine/Converter/BL_ArmatureObject.cpp
@@ -120,8 +120,8 @@ static void game_copy_pose(bPose **dst, bPose *src, int copy_constraint)
if (copy_constraint) {
ListBase listb;
// copy all constraint for backward compatibility
- // BKE_copy_constraints NULLs listb, no need to make extern for this operation.
- BKE_copy_constraints(&listb, &pchan->constraints, false);
+ // BKE_constraints_copy NULLs listb, no need to make extern for this operation.
+ BKE_constraints_copy(&listb, &pchan->constraints, false);
pchan->constraints= listb;
}
else {
@@ -288,7 +288,7 @@ void BL_ArmatureObject::LoadConstraints(KX_BlenderSceneConverter* converter)
case CONSTRAINT_TYPE_TRANSFORM:
case CONSTRAINT_TYPE_DISTLIMIT:
case CONSTRAINT_TYPE_TRANSLIKE:
- cti = BKE_constraint_get_typeinfo(pcon);
+ cti = BKE_constraint_typeinfo_get(pcon);
gametarget = gamesubtarget = NULL;
if (cti && cti->get_constraint_targets) {
ListBase listb = { NULL, NULL };